/**
 * Project:     Internet Display
 * By:          Jim Abraham
 * Company:     ABEtronics.com
 * Created on:  11-30-22
 * Description: Display time, date, weather, stocks on display.
 * Hardware: Mega 2650, ESP32 (for Wifi connection), RTC, Touchscreen display, MP3 player.
 * Revised:12-8-22
 */
//-------------------------------------------------------------------------------------
// Libaries
//-------------------------------------------------------------------------------------
#include <Arduino.h>
#include <WiFi.h>
#include <WiFiMulti.h>
#include <HTTPClient.h>
#define USE_SERIAL Serial
//-------------------------------------------------------------------------------------
WiFiMulti wifiMulti;
//-------------------------------------------------------------------------
// Variables
//-------------------------------------------------------------------------
// Wifi Connection Information
//Home WiFi Network1 
//const char* ssid= "home";;
//const char* password="home pw"; 

//iPhone WiFi hotspot
//const char* ssid= iPhone";
//const char* password = "iPhone pw";

//Home WiFi Network2
  const char* ssid = "Home2";
  const char* password = "Home2 pw"; 
//-------------------------------------------------------------------------

String Get_website_data;
int loopcnt=0, hw=0;
int firstClosingBracket;
int incomingByte = 0; // for incoming serial data

//-------------------------------------------------------------------------------------
// Set-Up
//-------------------------------------------------------------------------------------
void setup() 
{
  USE_SERIAL.begin(115200);
  USE_SERIAL.flush();
  delay(2000);
  pinMode(21, OUTPUT);
  pinMode(22, OUTPUT);
  pinMode(23, OUTPUT);
//-------------------------------------------------------------------------
// Connect to WiFI Network.
//-------------------------------------------------------------------------
  wifiMulti.addAP(ssid, password);
}

//-------------------------------------------------------------------------------------
// Main Loop
//-------------------------------------------------------------------------------------
void loop() 
{
  digitalWrite(23, HIGH);
  //Check_for Port_Activity();    // Check for incomming charactors from Mega 2650
  //Get_HTTP_URL();               // Get HTTP Url
  //if (loopcnt>0){HTTP_http();}  // Get Data from Url and send to Mega 2650
  //delay(500);                   // delay
  
  // The following code returns a character received through the serial port.
  // reply only when you receive data:
  if (Serial.available() > 0) 
    {
      // read the incoming byte:
      incomingByte = Serial.read();
      //char incme=incomingByte;
      if (incomingByte == 87) //=W (Weather)
        {
          incomingByte = Serial.read();
          loopcnt= int(incomingByte)-48;  //1-4
        }
      if (incomingByte == 83) //=S (Stocks)
        {
          incomingByte = Serial.read();
          loopcnt= 4+int(incomingByte)-48;  //1-4 = 5-8
        }
      if (incomingByte == 84) //=T (Time-Date)
        {
          incomingByte = Serial.read();
          loopcnt= 8+int(incomingByte)-48;  //1-6 = 9-14
        }
    }
  if (loopcnt==1){Hermitage_Temp();}    //41°
  if (loopcnt==2){Hermitage_Weather();} //<div data-testid="wxPhrase" class="CurrentConditions--phraseValue--mZC_p">Cloudy</div>
  if (loopcnt==3){KY_Temp();}           //49°
  if (loopcnt==4){Gainesville_Temp();}  //77°
  
  if (loopcnt==5){Tesla_Stock_Price();}     //184.25
  if (loopcnt==6){Tesla_Price_Move_PCT();}  //+0.76%
  if (loopcnt==7){SP500_Index_Price();}     //3,966.76
  if (loopcnt==8){SP500_Price_Move_PCT();}  //-0.59%
  
  if (loopcnt==9){Current_Time();}     //3:00:25 PM
  if (loopcnt==10){Month_Year();}      //Nov 2022
  if (loopcnt==11){Day();}             //28
  if (loopcnt==12){DOW();}             //Monday
  if (loopcnt==13){Sun_Rise_Time();}   //7:24 am
  if (loopcnt==14){Sun_Set_Time();}    //4:54 pm
  if (loopcnt>0){HTTP_http();}
  delay(250);
  digitalWrite(23, LOW);
  delay(250);
  if((wifiMulti.run() != WL_CONNECTED)){digitalWrite(21, HIGH);}
}//main loop

//-------------------------------------------------------------------------------------
// Routines
//-------------------------------------------------------------------------------------

void HTTP_http()
//---------------------------------------------------------------------------
// wait for WiFi connection
//---------------------------------------------------------------------------
{
  if((wifiMulti.run() != WL_CONNECTED)){digitalWrite(21, HIGH);}
  
  if((wifiMulti.run() == WL_CONNECTED)) 
    {
      digitalWrite(21, LOW);
      digitalWrite(22, HIGH);
      HTTPClient http;
    http.begin(Get_website_data);       
    // start connection and send HTTP header
    int httpCode = http.GET();
    
    // httpCode will be negative on error
    if(httpCode > 0) 
      {
        // file found at server
        if(httpCode == HTTP_CODE_OK) 
          {
            String payload = http.getString();
            //---------------------------------------------------------------------------
            if (loopcnt==2)       //Weather = Fog, Fair, Sunny, Rainy, Partly Cloudy, Cloudy, Windy, Stormy
              {
                firstClosingBracket = payload.indexOf(">Su"); //returns position.
                if (firstClosingBracket>0){payload="1";} //SUNNY
                firstClosingBracket = payload.indexOf(">Ra"); //returns position.
                if (firstClosingBracket>0){payload="2";} //RAINY
                firstClosingBracket = payload.indexOf(">Cl"); //returns position.
                if (firstClosingBracket>0){payload="3";}//CLOUDY
                firstClosingBracket = payload.indexOf(">Wi"); //returns position.
                if (firstClosingBracket>0){payload="4";}//WINDY
                firstClosingBracket = payload.indexOf(">St"); //returns position.
                if (firstClosingBracket>0){payload="5";}//STORMY
                firstClosingBracket = payload.indexOf(">Fo"); //returns position.
                if (firstClosingBracket>0){payload="6";}//FOG
                firstClosingBracket = payload.indexOf(">Fa"); //returns position.
                if (firstClosingBracket>0){payload="7";}//FAIR
                firstClosingBracket = payload.indexOf(">Pa"); //returns position.
                if (firstClosingBracket>0){payload="8";}//PCLOUDY
                firstClosingBracket = payload.indexOf(">Mo"); //returns position.
                if (firstClosingBracket>0){payload="9";}//MCLOUDY
                firstClosingBracket = payload.indexOf(">Snow<"); //returns position.
                if (firstClosingBracket>0){payload="A";}//SNOW
                firstClosingBracket = payload.indexOf(">Snow Shower<"); //returns position.
                if (firstClosingBracket>0){payload="B";}//SNOW SHOWER
              }
              if (loopcnt==9)           //spaces   Current Time 3:00:25 PM
                {
                  payload.trim();       //remove spaces
                }
              if (loopcnt==10)           //spaces   Month-Year   Nov 2022
                {
                  payload.trim();       //remove spaces
                }
            //---------------------------------------------------------------------------
              USE_SERIAL.print("#");
              USE_SERIAL.print(payload);
              USE_SERIAL.print("*");
              loopcnt=0;
              digitalWrite(22, LOW);
          }
      } 
      else 
      {
        USE_SERIAL.printf("[HTTP] GET... failed, error: %s\n", http.errorToString(httpCode).c_str());
      }
    http.end();
  }
}
//-------------------------------------------------------------------------------------
// Weather
// W1-4, update every 30 min every day
//-------------------------------------------------------------------------------------
void Hermitage_Temp()       {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Hermitage_Weather()    {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void KY_Temp()              {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Gainesville_Temp()     {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
//-------------------------------------------------------------------------------------
// Stocks
//S1-4, update every 10 min 9:30-4 M-F
//-------------------------------------------------------------------------------------
void Tesla_Stock_Price()    {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Tesla_Price_Move_PCT() {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void SP500_Index_Price()    {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void SP500_Price_Move_PCT() {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
//-------------------------------------------------------------------------------------
// Time-Date
//T1-6, update every day at 2am
//-------------------------------------------------------------------------------------
void Current_Time()         {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Month_Year()           {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Day()                  {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void DOW()                  {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Sun_Rise_Time()        {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
void Sun_Set_Time()         {Get_website_data = "http://api.thingspeak.com/apps/thinghttp/send_request?api_key=key";}
//-------------------------------------------------------------------------------------
